#ifndef __vtkITKBilateralImageFilter_h_
#define __vtkITKBilateralImageFilter_h_

#include <vtkImageAlgorithm.h>
class VTK_EXPORT vtkITKBilateralImageFilter : public vtkImageAlgorithm
{
public:
  static vtkITKBilateralImageFilter* New();
  vtkTypeMacro(vtkITKBilateralImageFilter, vtkImageAlgorithm);

  typedef vtkITKBilateralImageFilter Self;

  // Set/get DomainSigma variable
  vtkSetMacro(DomainSigma, double);
  vtkGetMacro(DomainSigma, double);

  // Set/get RangeSigma variable
  vtkSetMacro(RangeSigma, double);
  vtkGetMacro(RangeSigma, double);

  // Set/get NumberOfRangeGaussianSamples variable
  vtkSetMacro(NumberOfRangeGaussianSamples, int);
  vtkGetMacro(NumberOfRangeGaussianSamples, int);

protected:
  vtkITKBilateralImageFilter();
  virtual ~vtkITKBilateralImageFilter();

  virtual int FillInputPortInformation(int port, vtkInformation *info);

  virtual int RequestUpdateExtent(vtkInformation *, vtkInformationVector **, vtkInformationVector *);

  virtual int RequestInformation(vtkInformation *vtkNotUsed(request), vtkInformationVector **inputVector, vtkInformationVector * outputVector);

  int RequestData(vtkInformation * info, vtkInformationVector **inputVector, vtkInformationVector *outputVector);

  void PrintSelf(ostream& os, vtkIndent indent);

private:
  vtkITKBilateralImageFilter(const vtkITKBilateralImageFilter&); // Purposely not implemented.
  void operator=(const vtkITKBilateralImageFilter&); // Purposely not implemented.

  template< class TInputPixel >
  bool Run(TInputPixel *, vtkImageData * input, vtkImageData * output);

  double DomainSigma;

  double RangeSigma;

  int NumberOfRangeGaussianSamples;

};

#endif
