/*=========================================================================

Program:   Visualization Toolkit
Module:    vtkBinaryBranchCountingImageFilter.h

Copyright (c) Xiaojie Zhao
All rights reserved.

This software is distributed WITHOUT ANY WARRANTY; without even
the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkBinaryBranchCountingImageFilter - Count branch numbers for the thinning
// result (using BinaryThinningImageFilter3D method in ImageSurfer) of the microscopy fibrin image.

#ifndef __vtkBinaryBranchCountingImageFilter_h
#define __vtkBinaryBranchCountingImageFilter_h

#include <vtkITKImageFilter.h>
#include "itkBinaryBallStructuringElement.h"
#include <itkBinaryBranchCountingImageFilter.h>

class VTK_EXPORT vtkBinaryBranchCountingImageFilter : public vtkITKImageFilter
{
public:

  static vtkBinaryBranchCountingImageFilter* New();
  vtkTypeMacro(vtkBinaryBranchCountingImageFilter, vtkITKImageFilter);
  void PrintSelf(ostream& os, vtkIndent indent);

  //BTX
  typedef Superclass::PixelType             PixelType;
  typedef Superclass::ITKImageType          ITKImageType;
  typedef Superclass::ITKInternalFilterType ITKInternalFilterType;
  typedef Superclass::ITKImageImportType    ITKImageImportType;
  typedef Superclass::ITKImageExportType    ITKImageExportType;
  typedef itk::BinaryBranchCountingImageFilter< ITKImageType, ITKImageType >
    ITKBinaryBranchCountingImageFilterType;
  //ETX

  vtkSetMacro(BranchCombineRadius, int);
  vtkGetMacro(BranchCombineRadius, int);
  vtkSetMacro(HandleBoundaryRadius, int);
  vtkGetMacro(HandleBoundaryRadius, int);

  void SetInputConnection(int port, vtkAlgorithmOutput* input) {vtkImageAlgorithm::SetInputConnection(port, input);}
  void SetInputConnection(vtkAlgorithmOutput* input) {vtkImageAlgorithm::SetInputConnection(input);}

protected:
  vtkBinaryBranchCountingImageFilter();
  ~vtkBinaryBranchCountingImageFilter();

	int  BranchCombineRadius;
	int  HandleBoundaryRadius;

  //BTX
  ITKBinaryBranchCountingImageFilterType::Pointer BinaryBranchCountingImageFilter;
  //ETX

protected:
  int UpdateInternalFilters();

private:
  vtkBinaryBranchCountingImageFilter(const vtkBinaryBranchCountingImageFilter&);  // Not implemented.
  void operator=(const vtkBinaryBranchCountingImageFilter&);  // Not implemented.
};

#endif
