/*=========================================================================

Program:   Visualization Toolkit
Module:    vtkBinaryDilateImageFilter.cxx

Copyright (c) Xiaojie Zhao
All rights reserved.

This software is distributed WITHOUT ANY WARRANTY; without even
the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
#include "vtkBinaryDilateImageFilter.h"

#include "vtkObjectFactory.h"
#include "vtkImageExport.h"
#include "vtkImageImport.h"
#include "vtkImageData.h"
#include "vtkInformationVector.h"
#include "vtkInformation.h"

vtkStandardNewMacro(vtkBinaryDilateImageFilter);

//----------------------------------------------------------------------------
vtkBinaryDilateImageFilter::vtkBinaryDilateImageFilter()
{
	// Set up number of input and output ports

	// Initialize the ITK-VTK glue.
	this->Init();

	// Set up the internal filter pipeline.
	this->BinaryDilateImageFilter = ITKBinaryDilateImageFilterType::New();

	// Set the first and last filters in the internal ITK pipeline.
	this->SetITKPipelineFirstFilter<ITKInternalFilterType>(this->BinaryDilateImageFilter);
	this->SetITKPipelineLastFilter<ITKInternalFilterType>(this->BinaryDilateImageFilter);
}

//----------------------------------------------------------------------------
vtkBinaryDilateImageFilter::~vtkBinaryDilateImageFilter()
{
}

//----------------------------------------------------------------------------
int vtkBinaryDilateImageFilter::UpdateInternalFilters()
{
	KernelType ball;
	ball.SetRadius(Radius);
	ball.CreateStructuringElement();
	this->BinaryDilateImageFilter->SetKernel( ball );

	this->BinaryDilateImageFilter->SetDilateValue(1.0);
	this->BinaryDilateImageFilter->SetForegroundValue(1.0);
	this->BinaryDilateImageFilter->SetBackgroundValue(0.0);
	this->BinaryDilateImageFilter->Update();

	return 1;
}

//----------------------------------------------------------------------------
void vtkBinaryDilateImageFilter::PrintSelf(ostream& os, vtkIndent indent)
{
	this->Superclass::PrintSelf(os,indent);
}
