/*=========================================================================

Program:   Visualization Toolkit
Module:    vtkBinaryDilateImageFilter.h

Copyright (c) Xiaojie Zhao
All rights reserved.

This software is distributed WITHOUT ANY WARRANTY; without even
the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkBinaryDilateImageFilter - peforms binary dilation of an input image

#ifndef __vtkBinaryDilateImageFilter_h
#define __vtkBinaryDilateImageFilter_h

#include <vtkITKImageFilter.h>
#include "itkBinaryBallStructuringElement.h"
#include <itkBinaryDilateImageFilter.h>

class VTK_EXPORT vtkBinaryDilateImageFilter : public vtkITKImageFilter
{
public:

	static vtkBinaryDilateImageFilter* New();
	vtkTypeMacro(vtkBinaryDilateImageFilter, vtkITKImageFilter);
	void PrintSelf(ostream& os, vtkIndent indent);

	//BTX
	typedef Superclass::PixelType             PixelType;
	typedef Superclass::ITKImageType          ITKImageType;
	typedef Superclass::ITKInternalFilterType ITKInternalFilterType;
	typedef Superclass::ITKImageImportType    ITKImageImportType;
	typedef Superclass::ITKImageExportType    ITKImageExportType;
	typedef itk::BinaryBallStructuringElement < PixelType, 3> KernelType;
	typedef itk::BinaryDilateImageFilter< ITKImageType, ITKImageType , KernelType>
		ITKBinaryDilateImageFilterType;
	//ETX

	vtkSetMacro(Radius, double);
	vtkGetMacro(Radius, double);

    void SetInputConnection(int port, vtkAlgorithmOutput* input) {vtkImageAlgorithm::SetInputConnection(port, input);}
    void SetInputConnection(vtkAlgorithmOutput* input) {vtkImageAlgorithm::SetInputConnection(input);}

protected:
	vtkBinaryDilateImageFilter();
	~vtkBinaryDilateImageFilter();

	double Radius;

	//BTX
	ITKBinaryDilateImageFilterType::Pointer BinaryDilateImageFilter;
	//ETX

protected:
	int UpdateInternalFilters();

private:
	vtkBinaryDilateImageFilter(const vtkBinaryDilateImageFilter&);  // Not implemented.
	void operator=(const vtkBinaryDilateImageFilter&);  // Not implemented.
};

#endif
