/*=========================================================================

Program:   Visualization Toolkit
Module:    vtkBinaryErodeImageFilter.cxx

Copyright (c) Xiaojie Zhao
All rights reserved.

This software is distributed WITHOUT ANY WARRANTY; without even
the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
#include "vtkBinaryErodeImageFilter.h"

#include "vtkObjectFactory.h"
#include "vtkImageExport.h"
#include "vtkImageImport.h"
#include "vtkImageData.h"
#include "vtkInformationVector.h"
#include "vtkInformation.h"

vtkStandardNewMacro(vtkBinaryErodeImageFilter);

//----------------------------------------------------------------------------
vtkBinaryErodeImageFilter::vtkBinaryErodeImageFilter()
{
	// Set up number of input and output ports

	// Initialize the ITK-VTK glue.
	this->Init();

	// Set up the internal filter pipeline.
	this->BinaryErodeImageFilter = ITKBinaryErodeImageFilterType::New();

	// Set the first and last filters in the internal ITK pipeline.
	this->SetITKPipelineFirstFilter<ITKInternalFilterType>(this->BinaryErodeImageFilter);
	this->SetITKPipelineLastFilter<ITKInternalFilterType>(this->BinaryErodeImageFilter);
}

//----------------------------------------------------------------------------
vtkBinaryErodeImageFilter::~vtkBinaryErodeImageFilter()
{
}

//----------------------------------------------------------------------------
int vtkBinaryErodeImageFilter::UpdateInternalFilters()
{
	KernelType ball;
	ball.SetRadius(Radius);
	ball.CreateStructuringElement();
	this->BinaryErodeImageFilter->SetKernel( ball );

	this->BinaryErodeImageFilter->SetErodeValue(1.0);
	this->BinaryErodeImageFilter->SetForegroundValue(1.0);
	this->BinaryErodeImageFilter->SetBackgroundValue(0.0);
	this->BinaryErodeImageFilter->SetBoundaryToForeground(true); 
	this->BinaryErodeImageFilter->Update();

	return 1;
}

//----------------------------------------------------------------------------
void vtkBinaryErodeImageFilter::PrintSelf(ostream& os, vtkIndent indent)
{
	this->Superclass::PrintSelf(os,indent);
}
