/*=========================================================================

Program:   Visualization Toolkit
Module:    vtkBinaryErodeImageFilter.h

Copyright (c) Xiaojie Zhao
All rights reserved.

This software is distributed WITHOUT ANY WARRANTY; without even
the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkBinaryErodeImageFilter - peforms erosion of an input image

#ifndef __vtkBinaryErodeImageFilter_h
#define __vtkBinaryErodeImageFilter_h

#include <vtkITKImageFilter.h>
#include "itkBinaryBallStructuringElement.h"
#include <itkBinaryErodeImageFilter.h>

class VTK_EXPORT vtkBinaryErodeImageFilter : public vtkITKImageFilter
{
public:

	static vtkBinaryErodeImageFilter* New();
	vtkTypeMacro(vtkBinaryErodeImageFilter, vtkITKImageFilter);
	void PrintSelf(ostream& os, vtkIndent indent);

	//BTX
	typedef Superclass::PixelType             PixelType;
	typedef Superclass::ITKImageType          ITKImageType;
	typedef Superclass::ITKInternalFilterType ITKInternalFilterType;
	typedef Superclass::ITKImageImportType    ITKImageImportType;
	typedef Superclass::ITKImageExportType    ITKImageExportType;
	typedef itk::BinaryBallStructuringElement < PixelType, 3> KernelType;
	typedef itk::BinaryErodeImageFilter< ITKImageType, ITKImageType , KernelType>
		ITKBinaryErodeImageFilterType;
	//ETX

	vtkSetMacro(Radius, double);
	vtkGetMacro(Radius, double);

    void SetInputConnection(int port, vtkAlgorithmOutput* input) {vtkImageAlgorithm::SetInputConnection(port, input);}
    void SetInputConnection(vtkAlgorithmOutput* input) {vtkImageAlgorithm::SetInputConnection(input);}
protected:
	vtkBinaryErodeImageFilter();
	~vtkBinaryErodeImageFilter();

	double Radius;

	//BTX
	ITKBinaryErodeImageFilterType::Pointer BinaryErodeImageFilter;
	//ETX

protected:
	int UpdateInternalFilters();

private:
	vtkBinaryErodeImageFilter(const vtkBinaryErodeImageFilter&);  // Not implemented.
	void operator=(const vtkBinaryErodeImageFilter&);  // Not implemented.
};

#endif
