/*=========================================================================

Program:   Visualization Toolkit
Module:    vtkBinaryMorphologicalClosingImageFilter.cxx

Copyright (c) Xiaojie Zhao
All rights reserved.

This software is distributed WITHOUT ANY WARRANTY; without even
the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
#include "vtkBinaryMorphologicalClosingImageFilter.h"

#include "vtkObjectFactory.h"
#include "vtkImageExport.h"
#include "vtkImageImport.h"
#include "vtkImageData.h"
#include "vtkInformationVector.h"
#include "vtkInformation.h"

vtkStandardNewMacro(vtkBinaryMorphologicalClosingImageFilter);

//----------------------------------------------------------------------------
vtkBinaryMorphologicalClosingImageFilter::vtkBinaryMorphologicalClosingImageFilter()
{
	// Set up number of input and output ports

	// Initialize the ITK-VTK glue.
	this->Init();

	// Set up the internal filter pipeline.
	this->BinaryMorphologicalClosingImageFilter = ITKBinaryMorphologicalClosingImageFilterType::New();

	// Set the first and last filters in the internal ITK pipeline.
	this->SetITKPipelineFirstFilter<ITKInternalFilterType>(this->BinaryMorphologicalClosingImageFilter);
	this->SetITKPipelineLastFilter<ITKInternalFilterType>(this->BinaryMorphologicalClosingImageFilter);
}

//----------------------------------------------------------------------------
vtkBinaryMorphologicalClosingImageFilter::~vtkBinaryMorphologicalClosingImageFilter()
{
}

//----------------------------------------------------------------------------
int vtkBinaryMorphologicalClosingImageFilter::UpdateInternalFilters()
{
	KernelType ball;
	ball.SetRadius(Radius);
	ball.CreateStructuringElement();
	this->BinaryMorphologicalClosingImageFilter->SetKernel( ball );

	this->BinaryMorphologicalClosingImageFilter->SetForegroundValue(1.0);
	this->BinaryMorphologicalClosingImageFilter->SetSafeBorder(true); 
	this->BinaryMorphologicalClosingImageFilter->Update();

	return 1;
}

//----------------------------------------------------------------------------
void vtkBinaryMorphologicalClosingImageFilter::PrintSelf(ostream& os, vtkIndent indent)
{
	this->Superclass::PrintSelf(os,indent);
}
