/*=========================================================================

Program:   Visualization Toolkit
Module:    vtkBinaryMorphologicalClosingImageFilter

Copyright (c) Xiaojie Zhao
All rights reserved.

This software is distributed WITHOUT ANY WARRANTY; without even
the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkBinaryMorphologicalClosingImageFilter - peforms closing of an input image

#ifndef __vtkBinaryMorphologicalClosingImageFilter_h
#define __vtkBinaryMorphologicalClosingImageFilter_h

#include <vtkITKImageFilter.h>
#include "itkBinaryBallStructuringElement.h"
#include <itkBinaryMorphologicalClosingImageFilter.h>

class VTK_EXPORT vtkBinaryMorphologicalClosingImageFilter : public vtkITKImageFilter
{
public:

  static vtkBinaryMorphologicalClosingImageFilter* New();
  vtkTypeMacro(vtkBinaryMorphologicalClosingImageFilter, vtkITKImageFilter);
  void PrintSelf(ostream& os, vtkIndent indent);

  //BTX
  typedef Superclass::PixelType             PixelType;
  typedef Superclass::ITKImageType          ITKImageType;
  typedef Superclass::ITKInternalFilterType ITKInternalFilterType;
  typedef Superclass::ITKImageImportType    ITKImageImportType;
  typedef Superclass::ITKImageExportType    ITKImageExportType;
  typedef itk::BinaryBallStructuringElement < PixelType, 3> KernelType;
  typedef itk::BinaryMorphologicalClosingImageFilter< ITKImageType, ITKImageType , KernelType>
    ITKBinaryMorphologicalClosingImageFilterType;
  //ETX

  vtkSetMacro(Radius, double);
  vtkGetMacro(Radius, double);
  //vtkSetMacro(UpperThreshold, double);
  //vtkGetMacro(UpperThreshold, double);
  //vtkSetMacro(OutsideValue, double);
  //vtkSetMacro(InsideValue, double);
  void SetInputConnection(int port, vtkAlgorithmOutput* input) {vtkImageAlgorithm::SetInputConnection(port, input);}
  void SetInputConnection(vtkAlgorithmOutput* input) {vtkImageAlgorithm::SetInputConnection(input);}

protected:
  vtkBinaryMorphologicalClosingImageFilter();
  ~vtkBinaryMorphologicalClosingImageFilter();

  double Radius;
  //double UpperThreshold;
  //double OutsideValue;
  //double InsideValue;

  //BTX
  ITKBinaryMorphologicalClosingImageFilterType::Pointer BinaryMorphologicalClosingImageFilter;
  //ETX

protected:
  int UpdateInternalFilters();

private:
  vtkBinaryMorphologicalClosingImageFilter(const vtkBinaryMorphologicalClosingImageFilter&);  // Not implemented.
  void operator=(const vtkBinaryMorphologicalClosingImageFilter&);  // Not implemented.
};

#endif
