/*=========================================================================

Program:   Visualization Toolkit
Module:    vtkBinaryMorphologicalOpeningImageFilter.cxx

Copyright (c) Xiaojie Zhao
All rights reserved.

This software is distributed WITHOUT ANY WARRANTY; without even
the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
#include "vtkBinaryMorphologicalOpeningImageFilter.h"

#include "vtkObjectFactory.h"
#include "vtkImageExport.h"
#include "vtkImageImport.h"
#include "vtkImageData.h"
#include "vtkInformationVector.h"
#include "vtkInformation.h"

vtkStandardNewMacro(vtkBinaryMorphologicalOpeningImageFilter);

//----------------------------------------------------------------------------
vtkBinaryMorphologicalOpeningImageFilter::vtkBinaryMorphologicalOpeningImageFilter()
{
	// Set up number of input and output ports

	// Initialize the ITK-VTK glue.
	this->Init();

	// Set up the internal filter pipeline.
	this->BinaryMorphologicalOpeningImageFilter = ITKBinaryMorphologicalOpeningImageFilterType::New();

	// Set the first and last filters in the internal ITK pipeline.
	this->SetITKPipelineFirstFilter<ITKInternalFilterType>(this->BinaryMorphologicalOpeningImageFilter);
	this->SetITKPipelineLastFilter<ITKInternalFilterType>(this->BinaryMorphologicalOpeningImageFilter);
}

//----------------------------------------------------------------------------
vtkBinaryMorphologicalOpeningImageFilter::~vtkBinaryMorphologicalOpeningImageFilter()
{
}

//----------------------------------------------------------------------------
int vtkBinaryMorphologicalOpeningImageFilter::UpdateInternalFilters()
{
	KernelType ball;
	ball.SetRadius(Radius);
	ball.CreateStructuringElement();
	this->BinaryMorphologicalOpeningImageFilter->SetKernel( ball );

	this->BinaryMorphologicalOpeningImageFilter->SetForegroundValue(1.0);
	this->BinaryMorphologicalOpeningImageFilter->Update();

	return 1;
}

//----------------------------------------------------------------------------
void vtkBinaryMorphologicalOpeningImageFilter::PrintSelf(ostream& os, vtkIndent indent)
{
	this->Superclass::PrintSelf(os,indent);
}
