/*=========================================================================

Program:   Visualization Toolkit
Module:    vtkBinaryMorphologicalOpeningImageFilter

Copyright (c) Xiaojie Zhao
All rights reserved.

This software is distributed WITHOUT ANY WARRANTY; without even
the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkBinaryMorphologicalOpeningImageFilter - peforms opening of an input image

#ifndef __vtkBinaryMorphologicalOpeningImageFilter_h
#define __vtkBinaryMorphologicalOpeningImageFilter_h

#include <vtkITKImageFilter.h>
#include "itkBinaryBallStructuringElement.h"
#include <itkBinaryMorphologicalOpeningImageFilter.h>

class VTK_EXPORT vtkBinaryMorphologicalOpeningImageFilter : public vtkITKImageFilter
{
public:

	static vtkBinaryMorphologicalOpeningImageFilter* New();
	vtkTypeMacro(vtkBinaryMorphologicalOpeningImageFilter, vtkITKImageFilter);
	void PrintSelf(ostream& os, vtkIndent indent);

	//BTX
	typedef Superclass::PixelType             PixelType;
	typedef Superclass::ITKImageType          ITKImageType;
	typedef Superclass::ITKInternalFilterType ITKInternalFilterType;
	typedef Superclass::ITKImageImportType    ITKImageImportType;
	typedef Superclass::ITKImageExportType    ITKImageExportType;
	typedef itk::BinaryBallStructuringElement < PixelType, 3> KernelType;
	typedef itk::BinaryMorphologicalOpeningImageFilter< ITKImageType, ITKImageType , KernelType>
		ITKBinaryMorphologicalOpeningImageFilterType;
	//ETX

	vtkSetMacro(Radius, double);
	vtkGetMacro(Radius, double);

    void SetInputConnection(int port, vtkAlgorithmOutput* input) {vtkImageAlgorithm::SetInputConnection(port, input);}
    void SetInputConnection(vtkAlgorithmOutput* input) {vtkImageAlgorithm::SetInputConnection(input);}
protected:
	vtkBinaryMorphologicalOpeningImageFilter();
	~vtkBinaryMorphologicalOpeningImageFilter();

	double Radius;

	//BTX
	ITKBinaryMorphologicalOpeningImageFilterType::Pointer BinaryMorphologicalOpeningImageFilter;
	//ETX

protected:
	int UpdateInternalFilters();

private:
	vtkBinaryMorphologicalOpeningImageFilter(const vtkBinaryMorphologicalOpeningImageFilter&);  // Not implemented.
	void operator=(const vtkBinaryMorphologicalOpeningImageFilter&);  // Not implemented.
};

#endif
