/*=========================================================================

Program:   Visualization Toolkit
Module:    vtkBinaryPruningImageFilter3D.h

Copyright (c) Xiaojie Zhao
All rights reserved.

This software is distributed WITHOUT ANY WARRANTY; without even
the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkBinaryPruningImageFilter3D - peforms pruning of an binary skeleton 
// input image (3D)

#ifndef __vtkBinaryPruningImageFilter3D_h
#define __vtkBinaryPruningImageFilter3D_h

#include <vtkITKImageFilter.h>
#include "itkBinaryBallStructuringElement.h"
#include <itkBinaryPruningImageFilter3D.h>

class VTK_EXPORT vtkBinaryPruningImageFilter3D : public vtkITKImageFilter
{
public:

  static vtkBinaryPruningImageFilter3D* New();
  vtkTypeMacro(vtkBinaryPruningImageFilter3D, vtkITKImageFilter);
  void PrintSelf(ostream& os, vtkIndent indent);

  //BTX
  typedef Superclass::PixelType             PixelType;
  typedef Superclass::ITKImageType          ITKImageType;
  typedef Superclass::ITKInternalFilterType ITKInternalFilterType;
  typedef Superclass::ITKImageImportType    ITKImageImportType;
  typedef Superclass::ITKImageExportType    ITKImageExportType;
  typedef itk::BinaryPruningImageFilter3D< ITKImageType, ITKImageType >
    ITKBinaryPruningImageFilter3DType;
  //ETX

  vtkSetMacro(Iteration, int);
  vtkGetMacro(Iteration, int);

  void SetInputConnection(int port, vtkAlgorithmOutput* input) {vtkImageAlgorithm::SetInputConnection(port, input);}
  void SetInputConnection(vtkAlgorithmOutput* input) {vtkImageAlgorithm::SetInputConnection(input);}

protected:
  vtkBinaryPruningImageFilter3D();
  ~vtkBinaryPruningImageFilter3D();

  int Iteration;

  //BTX
  ITKBinaryPruningImageFilter3DType::Pointer BinaryPruningImageFilter3D;
  //ETX

protected:
  int UpdateInternalFilters();

private:
  vtkBinaryPruningImageFilter3D(const vtkBinaryPruningImageFilter3D&);  // Not implemented.
  void operator=(const vtkBinaryPruningImageFilter3D&);  // Not implemented.
};

#endif
