/*=========================================================================

Program:   Visualization Toolkit
Module:    vtkBinaryThinningImageFilter3D.h

Copyright (c) Xiaojie Zhao
All rights reserved.

This software is distributed WITHOUT ANY WARRANTY; without even
the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkBinaryThinningImageFilter3D - peforms the 3D thinning algorithm
// http://www.insight-journal.org/browse/publication/181/

#ifndef __vtkBinaryThinningImageFilter3D_h
#define __vtkBinaryThinningImageFilter3D_h

#include <vtkITKImageFilter.h>

#include <itkBinaryThinningImageFilter3D.h>

class VTK_EXPORT vtkBinaryThinningImageFilter3D : public vtkITKImageFilter
{
public:

	static vtkBinaryThinningImageFilter3D* New();
	vtkTypeMacro(vtkBinaryThinningImageFilter3D, vtkITKImageFilter);
	void PrintSelf(ostream& os, vtkIndent indent);

	//BTX
	typedef Superclass::PixelType             PixelType;
	typedef Superclass::ITKImageType          ITKImageType;
	typedef Superclass::ITKInternalFilterType ITKInternalFilterType;
	typedef Superclass::ITKImageImportType    ITKImageImportType;
	typedef Superclass::ITKImageExportType    ITKImageExportType;
	typedef itk::BinaryThinningImageFilter3D< ITKImageType, ITKImageType >
		ITKBinaryThinningFilter3DType;
	//ETX
    
    void SetInputConnection(int port, vtkAlgorithmOutput* input) {vtkImageAlgorithm::SetInputConnection(port, input);}
    void SetInputConnection(vtkAlgorithmOutput* input) {vtkImageAlgorithm::SetInputConnection(input);}

protected:
	vtkBinaryThinningImageFilter3D();
	~vtkBinaryThinningImageFilter3D();

	//BTX
	ITKBinaryThinningFilter3DType::Pointer BinaryThinningFilter3D;
	//ETX

protected:
	int UpdateInternalFilters();

private:
	vtkBinaryThinningImageFilter3D(const vtkBinaryThinningImageFilter3D&);  // Not implemented.
	void operator=(const vtkBinaryThinningImageFilter3D&);  // Not implemented.
};

#endif
