/*=========================================================================

Program:   Visualization Toolkit
Module:    vtkGaussianBlurImageFilter.cxx

Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
All rights reserved.
See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

This software is distributed WITHOUT ANY WARRANTY; without even
the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
#include "vtkBinaryThresholdImageFilter.h"

#include "vtkObjectFactory.h"
#include "vtkImageExport.h"
#include "vtkImageImport.h"
#include "vtkImageData.h"
#include "vtkInformationVector.h"
#include "vtkInformation.h"

//#include <qapplication.h>
//#include <qpushbutton.h>

vtkStandardNewMacro(vtkBinaryThresholdImageFilter);

//----------------------------------------------------------------------------
vtkBinaryThresholdImageFilter::vtkBinaryThresholdImageFilter()
{
	// Set up number of input and output ports

	// Initialize the ITK-VTK glue.
	this->Init();

	// Set up the internal filter pipeline.
	this->BinaryThresholdFilter = ITKBinaryThresholdFilterType::New();

	// Set the first and last filters in the internal ITK pipeline.
	this->SetITKPipelineFirstFilter<ITKInternalFilterType>(this->BinaryThresholdFilter);
	this->SetITKPipelineLastFilter<ITKInternalFilterType>(this->BinaryThresholdFilter);
}

//----------------------------------------------------------------------------
vtkBinaryThresholdImageFilter::~vtkBinaryThresholdImageFilter()
{
}

//----------------------------------------------------------------------------
int vtkBinaryThresholdImageFilter::UpdateInternalFilters()
{
	this->BinaryThresholdFilter->SetOutsideValue( OutsideValue );
	this->BinaryThresholdFilter->SetInsideValue( InsideValue );
	this->BinaryThresholdFilter->SetLowerThreshold( LowerThreshold );
	this->BinaryThresholdFilter->SetUpperThreshold( UpperThreshold );
	this->BinaryThresholdFilter->Update();

	//QApplication a;//( 0, "" ); 
	//QPushButton quit( "Quit", 0 );
	//quit.resize( 75, 30 );
	//quit.setFont( QFont( "Times", 18, QFont::Bold ) );
	//QObject::connect( &quit, SIGNAL(clicked()), &a, SLOT(quit()) );
	//qtapp.setMainWidget( &quit );
	//quit.show();
	//return a.exec();

	return 1;
}

//----------------------------------------------------------------------------
void vtkBinaryThresholdImageFilter::PrintSelf(ostream& os, vtkIndent indent)
{
	this->Superclass::PrintSelf(os,indent);
}
