/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkBinaryThresholdImageFilter.h

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkBinaryThresholdImageFilter - peforms Binary Threshold Segmentation of an input image
// .SECTION Description
// vtkMyImageShiftFilter is a filter to generate scalar values from a
// dataset.  The scalar values lie within a user specified range, and
// are generated by computing a projection of each dataset point onto
// a line. The line can be oriented arbitrarily. A typical example is
// to generate scalars based on elevation or height above a plane.

#ifndef __vtkBinaryThresholdImageFilter_h
#define __vtkBinaryThresholdImageFilter_h

#include <vtkITKImageFilter.h>

#include <itkBinaryThresholdImageFilter.h>

class VTK_EXPORT vtkBinaryThresholdImageFilter : public vtkITKImageFilter
{
public:

  static vtkBinaryThresholdImageFilter* New();
  vtkTypeMacro(vtkBinaryThresholdImageFilter, vtkITKImageFilter);
  void PrintSelf(ostream& os, vtkIndent indent);

  //BTX
  typedef Superclass::PixelType             PixelType;
  typedef Superclass::ITKImageType          ITKImageType;
  typedef Superclass::ITKInternalFilterType ITKInternalFilterType;
  typedef Superclass::ITKImageImportType    ITKImageImportType;
  typedef Superclass::ITKImageExportType    ITKImageExportType;
  typedef itk::BinaryThresholdImageFilter< ITKImageType, ITKImageType >
    ITKBinaryThresholdFilterType;
  //ETX

  vtkSetMacro(LowerThreshold, double);
  vtkGetMacro(LowerThreshold, double);
  vtkSetMacro(UpperThreshold, double);
  vtkGetMacro(UpperThreshold, double);
  vtkSetMacro(OutsideValue, double);
  vtkSetMacro(InsideValue, double);
  void SetInputConnection(int port, vtkAlgorithmOutput* input) {vtkImageAlgorithm::SetInputConnection(port, input);}
  void SetInputConnection(vtkAlgorithmOutput* input) {vtkImageAlgorithm::SetInputConnection(input);}

protected:
  vtkBinaryThresholdImageFilter();
  ~vtkBinaryThresholdImageFilter();

  double LowerThreshold;
  double UpperThreshold;
  double OutsideValue;
  double InsideValue;

  //BTX
  ITKBinaryThresholdFilterType::Pointer BinaryThresholdFilter;
  //ETX

protected:
  int UpdateInternalFilters();

private:
  vtkBinaryThresholdImageFilter(const vtkBinaryThresholdImageFilter&);  // Not implemented.
  void operator=(const vtkBinaryThresholdImageFilter&);  // Not implemented.
};

#endif
