#include "vtkContourWithPreviewFilter.h"

#include "vtkObjectFactory.h"
#include "vtkImageData.h"
#include "vtkInformationVector.h"
#include "vtkInformation.h"

#include "pqDataRepresentation.h"
#include "pqActiveObjects.h"
#include "vtkDiscretizableColorTransferFunction.h"
#include "pqScalarsToColors.h"
#include "vtkSMProxy.h"
#include "pqScalarOpacityFunction.h"
#include "vtkPiecewiseFunction.h"
#include "vtkColorTransferFunction.h"
#include "vtkSMPropertyHelper.h"
#include "pqSettings.h"
#include "pqApplicationCore.h"
#include "pqPropertiesPanel.h"
#include "pqPipelineRepresentation.h"
#include "pqObjectInspectorWidget.h"
#include "pqAutoApplyReaction.h"

vtkStandardNewMacro(vtkContourWithPreviewFilter);

//----------------------------------------------------------------------------
vtkContourWithPreviewFilter::vtkContourWithPreviewFilter()
{   
    thresholdFilter = vtkImageThreshold::New();

    /** AutoUpdate code copied from pqColorMapEditor.cxx in ParaView 4.0.1 */
    /*
    this->Internals->Ui.AutoUpdate->setChecked(val);
    this->updateIfNeeded();
    */

    autoApplyBefore = pqPropertiesPanel::autoApply();

    //pqAutoApplyReaction *autoapply = new pqAutoApplyReaction();

    
    
    /*
    pqSettings* settings = pqApplicationCore::instance()->settings();
    if ( settings ) {
      settings->setValue("autoAccept", true);
      
    }
    pqPropertiesPanel::setAutoApply(true);
    pqPropertiesPanel::setAutoApplyDelay(300);
    
    pqPipelineRepresentation::onInputChanged()
    */
    

    ifInit = false;
}

//----------------------------------------------------------------------------
vtkContourWithPreviewFilter::~vtkContourWithPreviewFilter()
{
    if(thresholdFilter) {
        thresholdFilter->Delete();
    }

    /*
    pqSettings* settings = pqApplicationCore::instance()->settings();
    if ( settings ) {
      settings->setValue("autoAccept", autoApplyBefore);
    }
    pqPropertiesPanel::setAutoApply(autoApplyBefore);
    */
}

int vtkContourWithPreviewFilter::RequestData(
  vtkInformation *request,
  vtkInformationVector **inputVector,
  vtkInformationVector *outputVector)
{  
    pqPropertiesPanel::setAutoApply(true);
    //pqObjectInspectorWidget::setAutoAccept(true);
    pqDataRepresentation* repr =
    pqActiveObjects::instance().activeRepresentation();

    if(repr && !ifInit) {
        vtkSMProxy* lutProxy = repr->getLookupTable()->getProxy();
        double rgbPoints[] = {0,   0, 0, 0,
                              0.3, 0, 0, 0,
                              1,   1, 1, 1};
        vtkSMPropertyHelper(lutProxy, "RGBPoints").Set(rgbPoints, 12);
        lutProxy->UpdateVTKObjects();
        ifInit = true;
    }

    
    thresholdFilter->SetInputData(this->GetInput());    
    thresholdFilter->ThresholdByLower(isovalue);
    thresholdFilter->SetInValue(0);
    thresholdFilter->SetOutValue(1);
    thresholdFilter->Update();
    
    vtkInformation *outInfo = outputVector->GetInformationObject(0);
    vtkDataSet *output
    = dynamic_cast<vtkDataSet*>(outInfo->Get(vtkDataObject::DATA_OBJECT()));

    if (!output)
    {
		vtkErrorMacro("Dataset is not present.");
		return 0;
    }

    output->ShallowCopy((vtkDataObject*)thresholdFilter->GetOutput());
    pqPropertiesPanel::setAutoApply(false);
	return 1;
}

//----------------------------------------------------------------------------
void vtkContourWithPreviewFilter::PrintSelf(ostream& os, vtkIndent indent)
{
  this->Superclass::PrintSelf(os,indent);
}
