/*=========================================================================

Program:   Visualization Toolkit
Module:    vtkDanielssonDistanceMapImageFilter

Copyright (c) Xiaojie Zhao
All rights reserved.

This software is distributed WITHOUT ANY WARRANTY; without even
the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkDanielssonDistanceMapImageFilter - calculate the Danielsson Distance Map of
// the input binary image

#ifndef __vtkDanielssonDistanceMapImageFilter_h
#define __vtkDanielssonDistanceMapImageFilter_h

#include <vtkITKImageFilter.h>

#include <itkDanielssonDistanceMapImageFilter.h>

class VTK_EXPORT vtkDanielssonDistanceMapImageFilter : public vtkITKImageFilter
{
public:

	static vtkDanielssonDistanceMapImageFilter* New();
	vtkTypeMacro(vtkDanielssonDistanceMapImageFilter, vtkITKImageFilter);
	void PrintSelf(ostream& os, vtkIndent indent);

	//BTX
	typedef Superclass::PixelType             PixelType;
	typedef Superclass::ITKImageType          ITKImageType;
	typedef Superclass::ITKInternalFilterType ITKInternalFilterType;
	typedef Superclass::ITKImageImportType    ITKImageImportType;
	typedef Superclass::ITKImageExportType    ITKImageExportType;
	typedef itk::DanielssonDistanceMapImageFilter< ITKImageType, ITKImageType >
		ITKDanielssonDistanceMapFilterType;
	//ETX
    void SetInputConnection(int port, vtkAlgorithmOutput* input) {vtkImageAlgorithm::SetInputConnection(port, input);}
    void SetInputConnection(vtkAlgorithmOutput* input) {vtkImageAlgorithm::SetInputConnection(input);}

protected:
	vtkDanielssonDistanceMapImageFilter();
	~vtkDanielssonDistanceMapImageFilter();

	//BTX
	ITKDanielssonDistanceMapFilterType::Pointer DanielssonDistanceMapFilter;
	//ETX

protected:
	int UpdateInternalFilters();

private:
	vtkDanielssonDistanceMapImageFilter(const vtkDanielssonDistanceMapImageFilter&);  // Not implemented.
	void operator=(const vtkDanielssonDistanceMapImageFilter&);  // Not implemented.
};

#endif
