#ifndef __vtkITKInverseDeconvolutionImageFilter_h_
#define __vtkITKInverseDeconvolutionImageFilter_h_

#include <vtkImageAlgorithm.h>
class VTK_EXPORT vtkITKInverseDeconvolutionImageFilter : public vtkImageAlgorithm
{
public:
  static vtkITKInverseDeconvolutionImageFilter* New();
  vtkTypeMacro(vtkITKInverseDeconvolutionImageFilter, vtkImageAlgorithm);

  typedef vtkITKInverseDeconvolutionImageFilter Self;

  // Set/get KernelZeroMagnitudeThreshold variable
  vtkSetMacro(KernelZeroMagnitudeThreshold, double);
  vtkGetMacro(KernelZeroMagnitudeThreshold, double);

  // Set/get Normalize variable
  vtkSetMacro(Normalize, int);
  vtkGetMacro(Normalize, int);

  enum {
    ZERO_PAD = 0,
    ZERO_FLUX_NEUMANN_PAD = 1,
    PERIODIC_PAD = 2
  };

  typedef int BoundaryConditionType;

  // Set/get BoundaryCondition variable
  vtkSetMacro(BoundaryCondition, int);
  vtkGetMacro(BoundaryCondition, int);

  enum {
    SAME = 0,
    VALID = 1
  };

  typedef int OutputRegionModeType;

  // Set/get OutputRegionMode variable
  vtkSetMacro(OutputRegionMode, int);
  vtkGetMacro(OutputRegionMode, int);

protected:
  vtkITKInverseDeconvolutionImageFilter();
  virtual ~vtkITKInverseDeconvolutionImageFilter();

  virtual int FillInputPortInformation(int port, vtkInformation *info);

  virtual int RequestUpdateExtent(vtkInformation *, vtkInformationVector **, vtkInformationVector *);

  virtual int RequestInformation(vtkInformation *vtkNotUsed(request), vtkInformationVector **inputVector, vtkInformationVector * outputVector);

  int RequestData(vtkInformation * info, vtkInformationVector **inputVector, vtkInformationVector *outputVector);

  void PrintSelf(ostream& os, vtkIndent indent);

private:
  vtkITKInverseDeconvolutionImageFilter(const vtkITKInverseDeconvolutionImageFilter&); // Purposely not implemented.
  void operator=(const vtkITKInverseDeconvolutionImageFilter&); // Purposely not implemented.

  template< class TInputPixel0, class TInputPixel1 >
  bool Run(TInputPixel0 *, TInputPixel1 *, vtkImageData * input0, vtkImageData * input1, vtkImageData * output);

  double KernelZeroMagnitudeThreshold;

  int Normalize;

  int BoundaryCondition;

  int OutputRegionMode;

};

#endif
