/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkMedianImageFilter.h

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkMedianImageFilter - peforms Gaussian blurring of an input image
// .SECTION Description
// vtkMyImageShiftFilter is a filter to generate scalar values from a
// dataset.  The scalar values lie within a user specified range, and
// are generated by computing a projection of each dataset point onto
// a line. The line can be oriented arbitrarily. A typical example is
// to generate scalars based on elevation or height above a plane.

#ifndef __vtkMedianImageFilter_h
#define __vtkMedianImageFilter_h

#include <vtkITKImageFilter.h>

#include <itkMedianImageFilter.h>

class VTK_EXPORT vtkMedianImageFilter : public vtkITKImageFilter
{
public:

  static vtkMedianImageFilter* New();
  vtkTypeMacro(vtkMedianImageFilter, vtkITKImageFilter);
  void PrintSelf(ostream& os, vtkIndent indent);

  //BTX
  typedef Superclass::PixelType             PixelType;
  typedef Superclass::ITKImageType          ITKImageType;
  typedef Superclass::ITKInternalFilterType ITKInternalFilterType;
  typedef Superclass::ITKImageImportType    ITKImageImportType;
  typedef Superclass::ITKImageExportType    ITKImageExportType;
  typedef itk::MedianImageFilter< ITKImageType, ITKImageType >
    ITKMedianFilterType;
  //ETX

  vtkSetVector3Macro(NeighborhoodRadius, int);
  vtkGetVector3Macro(NeighborhoodRadius, int);

  void SetInputConnection(int port, vtkAlgorithmOutput* input) {vtkImageAlgorithm::SetInputConnection(port, input);}
  void SetInputConnection(vtkAlgorithmOutput* input) {vtkImageAlgorithm::SetInputConnection(input);}

protected:
  vtkMedianImageFilter();
  ~vtkMedianImageFilter();

  int NeighborhoodRadius[3];

  //BTX
  ITKMedianFilterType::Pointer   MedianFilter;
  //ETX

protected:
  int UpdateInternalFilters();

private:
  vtkMedianImageFilter(const vtkMedianImageFilter&);  // Not implemented.
  void operator=(const vtkMedianImageFilter&);  // Not implemented.
};

#endif
