#ifndef __vtkITKProjectedLandweberDeconvolutionImageFilter_h_
#define __vtkITKProjectedLandweberDeconvolutionImageFilter_h_

#include <vtkImageAlgorithm.h>
class VTK_EXPORT vtkITKProjectedLandweberDeconvolutionImageFilter : public vtkImageAlgorithm
{
public:
  static vtkITKProjectedLandweberDeconvolutionImageFilter* New();
  vtkTypeMacro(vtkITKProjectedLandweberDeconvolutionImageFilter, vtkImageAlgorithm);

  typedef vtkITKProjectedLandweberDeconvolutionImageFilter Self;

  // Set/get Alpha variable
  vtkSetMacro(Alpha, double);
  vtkGetMacro(Alpha, double);

  // Set/get NumberOfIterations variable
  vtkSetMacro(NumberOfIterations, int);
  vtkGetMacro(NumberOfIterations, int);

  // Set/get Normalize variable
  vtkSetMacro(Normalize, int);
  vtkGetMacro(Normalize, int);

  enum {
    ZERO_PAD = 0,
    ZERO_FLUX_NEUMANN_PAD = 1,
    PERIODIC_PAD = 2
  };

  typedef int BoundaryConditionType;

  // Set/get BoundaryCondition variable
  vtkSetMacro(BoundaryCondition, int);
  vtkGetMacro(BoundaryCondition, int);

  enum {
    SAME = 0,
    VALID = 1
  };

  typedef int OutputRegionModeType;

  // Set/get OutputRegionMode variable
  vtkSetMacro(OutputRegionMode, int);
  vtkGetMacro(OutputRegionMode, int);

protected:
  vtkITKProjectedLandweberDeconvolutionImageFilter();
  virtual ~vtkITKProjectedLandweberDeconvolutionImageFilter();

  virtual int FillInputPortInformation(int port, vtkInformation *info);

  virtual int RequestUpdateExtent(vtkInformation *, vtkInformationVector **, vtkInformationVector *);

  virtual int RequestInformation(vtkInformation *vtkNotUsed(request), vtkInformationVector **inputVector, vtkInformationVector * outputVector);

  int RequestData(vtkInformation * info, vtkInformationVector **inputVector, vtkInformationVector *outputVector);

  void PrintSelf(ostream& os, vtkIndent indent);

private:
  vtkITKProjectedLandweberDeconvolutionImageFilter(const vtkITKProjectedLandweberDeconvolutionImageFilter&); // Purposely not implemented.
  void operator=(const vtkITKProjectedLandweberDeconvolutionImageFilter&); // Purposely not implemented.

  template< class TInputPixel0, class TInputPixel1 >
  bool Run(TInputPixel0 *, TInputPixel1 *, vtkImageData * input0, vtkImageData * input1, vtkImageData * output);

  double Alpha;

  int NumberOfIterations;

  int Normalize;

  int BoundaryCondition;

  int OutputRegionMode;

};

#endif
