#ifndef __vtkITKRichardsonLucyDeconvolutionImageFilter_h_
#define __vtkITKRichardsonLucyDeconvolutionImageFilter_h_

#include <vtkImageAlgorithm.h>
class VTK_EXPORT vtkITKRichardsonLucyDeconvolutionImageFilter : public vtkImageAlgorithm
{
public:
  static vtkITKRichardsonLucyDeconvolutionImageFilter* New();
  vtkTypeMacro(vtkITKRichardsonLucyDeconvolutionImageFilter, vtkImageAlgorithm);

  typedef vtkITKRichardsonLucyDeconvolutionImageFilter Self;

  // Set/get NumberOfIterations variable
  vtkSetMacro(NumberOfIterations, int);
  vtkGetMacro(NumberOfIterations, int);

  // Set/get Normalize variable
  vtkSetMacro(Normalize, int);
  vtkGetMacro(Normalize, int);

  enum {
    ZERO_PAD = 0,
    ZERO_FLUX_NEUMANN_PAD = 1,
    PERIODIC_PAD = 2
  };

  typedef int BoundaryConditionType;

  // Set/get BoundaryCondition variable
  vtkSetMacro(BoundaryCondition, int);
  vtkGetMacro(BoundaryCondition, int);

  enum {
    SAME = 0,
    VALID = 1
  };

  typedef int OutputRegionModeType;

  // Set/get OutputRegionMode variable
  vtkSetMacro(OutputRegionMode, int);
  vtkGetMacro(OutputRegionMode, int);

protected:
  vtkITKRichardsonLucyDeconvolutionImageFilter();
  virtual ~vtkITKRichardsonLucyDeconvolutionImageFilter();

  virtual int FillInputPortInformation(int port, vtkInformation *info);

  virtual int RequestUpdateExtent(vtkInformation *, vtkInformationVector **, vtkInformationVector *);

  virtual int RequestInformation(vtkInformation *vtkNotUsed(request), vtkInformationVector **inputVector, vtkInformationVector * outputVector);

  int RequestData(vtkInformation * info, vtkInformationVector **inputVector, vtkInformationVector *outputVector);

  void PrintSelf(ostream& os, vtkIndent indent);

private:
  vtkITKRichardsonLucyDeconvolutionImageFilter(const vtkITKRichardsonLucyDeconvolutionImageFilter&); // Purposely not implemented.
  void operator=(const vtkITKRichardsonLucyDeconvolutionImageFilter&); // Purposely not implemented.

  template< class TInputPixel0, class TInputPixel1 >
  bool Run(TInputPixel0 *, TInputPixel1 *, vtkImageData * input0, vtkImageData * input1, vtkImageData * output);

  int NumberOfIterations;

  int Normalize;

  int BoundaryCondition;

  int OutputRegionMode;

};

#endif
