#include "SCIFIOReader.h"
 
#include "vtkObjectFactory.h"
#include "vtkStreamingDemandDrivenPipeline.h"
#include "vtkInformationVector.h"
#include "vtkInformation.h"
#include "vtkDataObject.h"
#include "vtkSmartPointer.h"
#include "vtkVertexGlyphFilter.h"

#ifdef WIN32
#include <shellapi.h>
#endif

vtkStandardNewMacro(SCIFIOReader);
 
SCIFIOReader::SCIFIOReader()
{
// Detect if Java is installed
#ifdef WIN32
    if( (int)(ShellExecute(0,"open","javaw",0,0,SW_HIDE)) == ERROR_FILE_NOT_FOUND) {
        vtkWarningMacro("javaw.exe is not found. Install it from http://www.oracle.com/technetwork/java/javase/downloads/java-se-jre-7-download-432155.html");
    }
#endif
    this->FileName = NULL;
    this->SetNumberOfInputPorts(0);
    this->SetNumberOfOutputPorts(1);
	
	this->reader = ReaderType::New();
	this->connector = ConnectorType::New();
	this->spacing_filter = vtkImageChangeInformation::New();

    this->io = itk::SCIFIOImageIO::New();
    io->DebugOn();
}

SCIFIOReader::~SCIFIOReader()
{
	if( this->spacing_filter )
		this->spacing_filter->Delete();
	if( this->connector )
		this->connector = NULL;
	if( this->reader )
		this->reader = NULL;
}

int SCIFIOReader::RequestInformation(
  vtkInformation *vtkNotUsed(request),
  vtkInformationVector **vtkNotUsed(inputVector),
  vtkInformationVector *outputVector)
{	
	if (!this->FileName)
    {
		vtkErrorMacro(<< "A FileName must be specified.");
		return 0;
    }
	
	// Create an ITK reader and connect it to a Connector to get VTK output
	// --------------------------------------------------------------------
    this->reader->SetImageIO(io);
	this->reader->SetFileName(FileName);
    this->reader->Update();
	
    this->connector->SetInput(reader->GetOutput());
	this->connector->Update();
	
	vtkImageData *imageData = this->connector->GetOutput();
	// --------------------------------------------------------------------
	
	double spacing[3], origin[3];
	int extent[6];
	
	imageData->GetExtent(extent);
	imageData->GetOrigin(origin);
	imageData->GetSpacing(spacing);

	// get the info object
	vtkInformation *outInfo = outputVector->GetInformationObject(0);
	
	outInfo->Set(vtkDataObject::ORIGIN(),origin,3);
	outInfo->Set(vtkDataObject::SPACING(),spacing,3);
	outInfo->Set(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT(),extent,6);
	
	/* Old VTK function calls
	this->GetOutput()->SetNumberOfScalarComponents(1);
	this->GetOutput()->SetScalarType(VTK_FLOAT);
	*/
	vtkDataObject::SetPointDataActiveScalarInfo( outInfo, VTK_FLOAT, 1);
	
	return 1;
}
int SCIFIOReader::RequestData(
  vtkInformation *vtkNotUsed(request),
  vtkInformationVector **vtkNotUsed(inputVector),
  vtkInformationVector *outputVector)
{
	// Create an ITK reader and connect it to a Connector to get VTK output
	// --------------------------------------------------------------------
	this->reader->SetFileName(FileName);
    this->connector->SetInput(reader->GetOutput());
    this->connector->Update();

    this->spacing_filter->SetInputData( connector->GetOutput() );
    this->spacing_filter->SetSpacingScale(xyz_spacing);
    this->spacing_filter->Update();
	//vtkImageData *imageData = this->connector->GetOutput();
	// --------------------------------------------------------------------

	vtkInformation *outInfo = outputVector->GetInformationObject(0);
    vtkImageData *output = vtkImageData::SafeDownCast(
	  (outInfo->Get(vtkDataObject::DATA_OBJECT())));
	
	if (!output)
    {
		vtkErrorMacro("Output is not of type vtkImageData");
		return 0;
    }
	
	/*
	if (output->GetScalarType() != VTK_FLOAT)
	{
		vtkErrorMacro("Execute: This source only outputs floats.");
		return 1;
	}
	*/

    //output->ShallowCopy(this->connector->GetOutput());
    output->ShallowCopy(this->spacing_filter->GetOutput());
	return 1;
}
 
void SCIFIOReader::PrintSelf(ostream& os, vtkIndent indent)
{
	this->Superclass::PrintSelf(os,indent);
	
	os << indent << "File Name: "
      << (this->FileName ? this->FileName : "(none)") << "\n";
}
  
