#ifndef __SCIFIOReader__
#define __SCIFIOReader__
 
#include "vtkImageAlgorithm.h"

#include "itkImage.h"
#include "itkImageFileReader.h"
#include "itkImageToVTKImageFilter.h"
#include "itkSmartPointer.h"
#include "vtkImageChangeInformation.h"
#include "itkSCIFIOImageIO.h"

class SCIFIOReader: public vtkImageAlgorithm
{
public:
	vtkTypeMacro(SCIFIOReader,vtkImageAlgorithm);
	void PrintSelf(ostream& os, vtkIndent indent);
 
    static SCIFIOReader* New();
    // Description:
    // Specify file name of the input file.
    vtkSetStringMacro(FileName);
    vtkGetStringMacro(FileName);
 
	vtkSetVector3Macro(xyz_spacing, double);
    vtkGetVector3Macro(xyz_spacing, double);

protected:
    SCIFIOReader();
    ~SCIFIOReader();
	
    int RequestInformation(vtkInformation *, vtkInformationVector **, vtkInformationVector *);
    int RequestData(vtkInformation *, vtkInformationVector **, vtkInformationVector *);

	vtkImageChangeInformation* spacing_filter;
    double xyz_spacing[3];
 
	typedef float                                   PixelType;
	typedef itk::Image< PixelType, 3 >              ImageType;
	typedef itk::ImageFileReader< ImageType >       ReaderType;
	typedef itk::ImageToVTKImageFilter< ImageType > ConnectorType;
	itk::SCIFIOImageIO::Pointer io;

	ReaderType::Pointer    reader;
	ConnectorType::Pointer connector;
	
private:
    SCIFIOReader(const SCIFIOReader&);  // Not implemented.
    void operator=(const SCIFIOReader&);  // Not implemented.
 
    char* FileName;
};
 
#endif

