#include "vtkTiffVolumeReader.h"

#include <vtkObjectFactory.h>
#include <vtkSmartPointer.h>
#include <vtkStringArray.h>
#include <vtkStreamingDemandDrivenPipeline.h>

//-----------------------------------------------------------------------------
vtkStandardNewMacro(vtkTiffVolumeReader);

//-----------------------------------------------------------------------------
vtkTiffVolumeReader::vtkTiffVolumeReader()
{
  this->SetFileNames(vtkSmartPointer<vtkStringArray>::New());
  this->SetFileDimensionality(3);
  this->spacing_filter = vtkImageChangeInformation::New();
}

//-----------------------------------------------------------------------------
vtkTiffVolumeReader::~vtkTiffVolumeReader()
{
	if (this->spacing_filter)
		this->spacing_filter->Delete();
}

//-----------------------------------------------------------------------------
void vtkTiffVolumeReader::AddFileName(const char* fname)
{
   this->FileNames->InsertNextValue(fname);
}

//-----------------------------------------------------------------------------
const char* vtkTiffVolumeReader::GetFileName(unsigned int idx)
{
   return this->FileNames->GetValue(idx);
}

//-----------------------------------------------------------------------------
unsigned int vtkTiffVolumeReader::GetNumberOfFileNames()
{
   if (this->FileNames == NULL)
      return 0;
   else
      return this->FileNames->GetNumberOfValues();
   
}

//-----------------------------------------------------------------------------
void vtkTiffVolumeReader::RemoveAllFileNames()
{
   if (this->FileNames != NULL)
      this->FileNames->Reset();
   else
      this->SetFileNames(vtkSmartPointer<vtkStringArray>::New());
}

int vtkTiffVolumeReader::RequestData(
  vtkInformation *vtkNotUsed(request),
  vtkInformationVector **vtkNotUsed(inputVector),
  vtkInformationVector *outputVector)
{
    if(this->FileNames->GetNumberOfValues() == 1) {
        vtkErrorMacro("The input has only one image. Choose the 'TIFF 3D Stack (Single file)' option instead.");
        return 0;
    }

	this->SetFileNames( this->FileNames );
	
	this->spacing_filter->SetInputData(this->GetOutput());
	this->spacing_filter->SetOutputSpacing(xyz_spacing);
	this->spacing_filter->Update();
	
	vtkInformation *outInfo = outputVector->GetInformationObject(0);
    vtkImageData *output = vtkImageData::SafeDownCast(
	  (outInfo->Get(vtkDataObject::DATA_OBJECT())));
	
	if (!output)
    {
		vtkErrorMacro("Output is not of type vtkImageData");
		return 0;
    }
	
	output->ShallowCopy(this->spacing_filter->GetOutput());
	this->ExecuteDataWithInformation(output, outInfo);
	
	return 1;
}
