#ifndef __vtkITKTikhonovDeconvolutionImageFilter_h_
#define __vtkITKTikhonovDeconvolutionImageFilter_h_

#include <vtkImageAlgorithm.h>
class VTK_EXPORT vtkITKTikhonovDeconvolutionImageFilter : public vtkImageAlgorithm
{
public:
  static vtkITKTikhonovDeconvolutionImageFilter* New();
  vtkTypeMacro(vtkITKTikhonovDeconvolutionImageFilter, vtkImageAlgorithm);

  typedef vtkITKTikhonovDeconvolutionImageFilter Self;

  // Set/get RegularizationConstant variable
  vtkSetMacro(RegularizationConstant, double);
  vtkGetMacro(RegularizationConstant, double);

  // Set/get Normalize variable
  vtkSetMacro(Normalize, int);
  vtkGetMacro(Normalize, int);

  enum {
    ZERO_PAD = 0,
    ZERO_FLUX_NEUMANN_PAD = 1,
    PERIODIC_PAD = 2
  };

  typedef int BoundaryConditionType;

  // Set/get BoundaryCondition variable
  vtkSetMacro(BoundaryCondition, int);
  vtkGetMacro(BoundaryCondition, int);

  enum {
    SAME = 0,
    VALID = 1
  };

  typedef int OutputRegionModeType;

  // Set/get OutputRegionMode variable
  vtkSetMacro(OutputRegionMode, int);
  vtkGetMacro(OutputRegionMode, int);

protected:
  vtkITKTikhonovDeconvolutionImageFilter();
  virtual ~vtkITKTikhonovDeconvolutionImageFilter();

  virtual int FillInputPortInformation(int port, vtkInformation *info);

  virtual int RequestUpdateExtent(vtkInformation *, vtkInformationVector **, vtkInformationVector *);

  virtual int RequestInformation(vtkInformation *vtkNotUsed(request), vtkInformationVector **inputVector, vtkInformationVector * outputVector);

  int RequestData(vtkInformation * info, vtkInformationVector **inputVector, vtkInformationVector *outputVector);

  void PrintSelf(ostream& os, vtkIndent indent);

private:
  vtkITKTikhonovDeconvolutionImageFilter(const vtkITKTikhonovDeconvolutionImageFilter&); // Purposely not implemented.
  void operator=(const vtkITKTikhonovDeconvolutionImageFilter&); // Purposely not implemented.

  template< class TInputPixel0, class TInputPixel1 >
  bool Run(TInputPixel0 *, TInputPixel1 *, vtkImageData * input0, vtkImageData * input1, vtkImageData * output);

  double RegularizationConstant;

  int Normalize;

  int BoundaryCondition;

  int OutputRegionMode;

};

#endif
